﻿using SoundFingerprinting.Audio;
using SoundFingerprinting.Builder;
using SoundFingerprinting.Command;
using System;
using System.Collections.Concurrent;
using System.Threading;
using System.Threading.Tasks;

namespace SoundFingerprinting
{
    public class RunAsync
    {
        public static async Task Run(IModelService modelService, BlockingCollection<AudioSamples> collection, CancellationToken cancellationToken)
        {
            var consumerTask = QueryRealtimeData(modelService, collection, 5d, cancellationToken);
            await consumerTask.ConfigureAwait(false);
        }

       public static Task QueryRealtimeData(
       IModelService modelService,
       BlockingCollection<AudioSamples> source,
       double lengthOfASuccessfulMatch,
       CancellationToken cancellationToken)
       {
            var realtimeQuery = QueryCommandBuilder.Instance.BuildRealtimeQueryCommand()
                .From(source)
                .WithRealtimeQueryConfig(config =>
                {
                    config.ResultEntryFilter = new QueryMatchLengthFilter(lengthOfASuccessfulMatch);
                    config.SuccessCallback = entry =>
                    {
                        Console.WriteLine($"Got successful match for {entry.Track.Id}");
                    };
                    return config;
                })
                .UsingServices(modelService)
                .Query(cancellationToken);

            return realtimeQuery;
        }

    }

   
}
